@@ -14,7 +14,7 @@
 
 
 #include "grib_api_internal.h"
-#include <ctype.h>
+#include <cctype>
 /*
    This is used by make_class.pl
 
@@ -147,7 +147,7 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
     if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
         return;
 
-    grib_value_count(a, &count);
+    a->value_count(&count);
     size = size2 = count;
 
     print_offset(self->dumper.out, d, a);
@@ -159,10 +159,10 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
 
     if (size > 1) {
         values = (long*)grib_context_malloc_clear(a->context, sizeof(long) * size);
-        err    = grib_unpack_long(a, values, &size2);
+        err    = a->unpack_long(values, &size2);
     }
     else {
-        err = grib_unpack_long(a, &value, &size2);
+        err = a->unpack_long(&value, &size2);
     }
     Assert(size2 == size);
 
@@ -195,7 +195,7 @@ static void dump_long(grib_dumper* d, grib_accessor* a, const char* comment)
         grib_context_free(a->context, values);
     }
     else {
-        if (((a->flags & GRIB_ACCESSOR_FLAG_CAN_BE_MISSING) != 0) && grib_is_missing_internal(a))
+        if (((a->flags & GRIB_ACCESSOR_FLAG_CAN_BE_MISSING) != 0) && a->is_missing_internal())
             fprintf(self->dumper.out, "%s = MISSING;", a->name);
         else
             fprintf(self->dumper.out, "%s = %ld;", a->name, value);
@@ -224,12 +224,12 @@ static void dump_bits(grib_dumper* d, grib_accessor* a, const char* comment)
     int err       = 0;
     int isDouble  = 0;
 
-    switch (grib_accessor_get_native_type(a)) {
+    switch (a->get_native_type()) {
         case GRIB_TYPE_LONG:
-            grib_unpack_long(a, &lvalue, &size);
+            a->unpack_long(&lvalue, &size);
             break;
         case GRIB_TYPE_DOUBLE:
-            grib_unpack_double(a, &dvalue, &size);
+            a->unpack_double(&dvalue, &size);
             isDouble = 1;
             break;
         default:
@@ -269,7 +269,7 @@ static void dump_bits(grib_dumper* d, grib_accessor* a, const char* comment)
     else
         fprintf(self->dumper.out, "  ");
 
-    if (((a->flags & GRIB_ACCESSOR_FLAG_CAN_BE_MISSING) != 0) && grib_is_missing_internal(a))
+    if (((a->flags & GRIB_ACCESSOR_FLAG_CAN_BE_MISSING) != 0) && a->is_missing_internal())
         fprintf(self->dumper.out, "%s = MISSING;", a->name);
     else {
         if (isDouble)
@@ -292,7 +292,7 @@ static void dump_double(grib_dumper* d, grib_accessor* a, const char* comment)
     grib_dumper_default* self = (grib_dumper_default*)d;
     double value              = 0;
     size_t size               = 1;
-    int err                   = grib_unpack_double(a, &value, &size);
+    int err                   = a->unpack_double(&value, &size);
 
     if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
         return;
@@ -318,7 +318,7 @@ static void dump_double(grib_dumper* d, grib_accessor* a, const char* comment)
     else
         fprintf(self->dumper.out, "  ");
 
-    if (((a->flags & GRIB_ACCESSOR_FLAG_CAN_BE_MISSING) != 0) && grib_is_missing_internal(a))
+    if (((a->flags & GRIB_ACCESSOR_FLAG_CAN_BE_MISSING) != 0) && a->is_missing_internal())
         fprintf(self->dumper.out, "%s = MISSING;", a->name);
     else
         fprintf(self->dumper.out, "%s = %g;", a->name, value);
@@ -341,7 +341,7 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
     int tab         = 0;
     long count      = 0;
 
-    grib_value_count(a, &count);
+    a->value_count(&count);
     size = count;
     if (size == 1) {
         dump_string(d, a, comment);
@@ -354,7 +354,7 @@ static void dump_string_array(grib_dumper* d, grib_accessor* a, const char* comm
         return;
     }
 
-    err = grib_unpack_string_array(a, values, &size);
+    err = a->unpack_string_array(values, &size);
 
     if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
         return;
@@ -410,7 +410,7 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
         return;
     }
 
-    ecc__grib_get_string_length(a, &size);
+    grib_get_string_length_acc(a, &size);
     if (size == 0)
         return;
 
@@ -420,7 +420,7 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
         return;
     }
 
-    err = grib_unpack_string(a, value, &size);
+    err = a->unpack_string(value, &size);
     p   = value;
 
     while (*p) {
@@ -449,7 +449,7 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
     else
         fprintf(self->dumper.out, "  ");
 
-    if (((a->flags & GRIB_ACCESSOR_FLAG_CAN_BE_MISSING) != 0) && grib_is_missing_internal(a))
+    if (((a->flags & GRIB_ACCESSOR_FLAG_CAN_BE_MISSING) != 0) && a->is_missing_internal())
         fprintf(self->dumper.out, "%s = MISSING;", a->name);
     else
         fprintf(self->dumper.out, "%s = %s;", a->name, value);
@@ -466,77 +466,75 @@ static void dump_string(grib_dumper* d, grib_accessor* a, const char* comment)
 
 static void dump_bytes(grib_dumper* d, grib_accessor* a, const char* comment)
 {
-#if 0
-    grib_dumper_default *self = (grib_dumper_default*)d;
-    int i,k,err =0;
-    size_t more = 0;
-    size_t size = a->length;
-    unsigned char* buf = grib_context_malloc(d->context,size);
+//     grib_dumper_default *self = (grib_dumper_default*)d;
+//     int i,k,err =0;
+//     size_t more = 0;
+//     size_t size = a->length;
+//     unsigned char* buf = grib_context_malloc(d->context,size);
 
-    if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
-        return;
+//     if ( (a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
+//         return;
 
 
-    if (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY)
-        fprintf(self->dumper.out,"-READ ONLY- ");
+//     if (a->flags & GRIB_ACCESSOR_FLAG_READ_ONLY)
+//         fprintf(self->dumper.out,"-READ ONLY- ");
 
-    /*for(i = 0; i < d->depth ; i++) fprintf(self->dumper.out," ");*/
-    /*print_offset(self->dumper.out,self->begin,self->theEnd);*/
-    if ((d->option_flags & GRIB_DUMP_FLAG_TYPE) != 0)
-        fprintf(self->dumper.out,"%s ",a->creator->op);
+//     /*for(i = 0; i < d->depth ; i++) fprintf(self->dumper.out," ");*/
+//     /*print_offset(self->dumper.out,self->begin,self->theEnd);*/
+//     if ((d->option_flags & GRIB_DUMP_FLAG_TYPE) != 0)
+//         fprintf(self->dumper.out,"%s ",a->creator->op);
 
-    fprintf(self->dumper.out,"%s = %ld",a->name,a->length);
-    aliases(d,a);
-    fprintf(self->dumper.out," {");
+//     fprintf(self->dumper.out,"%s = %ld",a->name,a->length);
+//     aliases(d,a);
+//     fprintf(self->dumper.out," {");
 
-    if(!buf)
-    {
-        if(size == 0)
-            fprintf(self->dumper.out,"}\n");
-        else
-            fprintf(self->dumper.out," *** ERR cannot malloc(%ld) }\n",(long)size);
-        return;
-    }
+//     if(!buf)
+//     {
+//         if(size == 0)
+//             fprintf(self->dumper.out,"}\n");
+//         else
+//             fprintf(self->dumper.out," *** ERR cannot malloc(%ld) }\n",(long)size);
+//         return;
+//     }
 
-    fprintf(self->dumper.out,"\n");
+//     fprintf(self->dumper.out,"\n");
 
-    err = grib_unpack_bytes(a,buf,&size);
-    if(err){
-        grib_context_free(d->context,buf);
-        fprintf(self->dumper.out," *** ERR=%d (%s)  [grib_dumper_default::dump_bytes]\n}",err,grib_get_error_message(err));
-        return ;
-    }
+//     err = a->unpack_bytes(buf,&size);
+//     if(err){
+//         grib_context_free(d->context,buf);
+//         fprintf(self->dumper.out," *** ERR=%d (%s)  [grib_dumper_default::dump_bytes]\n}",err,grib_get_error_message(err));
+//         return ;
+//     }
 
-    if(size > 100) {
-        more = size - 100;
-        size = 100;
-    }
+//     if(size > 100) {
+//         more = size - 100;
+//         size = 100;
+//     }
 
-    k = 0;
-    /* if(size > 100) size = 100;  */
-    while(k < size)
-    {
-        int j;
-        for(i = 0; i < d->depth + 3 ; i++) fprintf(self->dumper.out," ");
-        for(j = 0; j < 16 && k < size; j++, k++)
-        {
-            fprintf(self->dumper.out,"%02x",buf[k]);
-            if(k != size-1)
-                fprintf(self->dumper.out,", ");
-        }
-        fprintf(self->dumper.out,"\n");
-    }
+//     k = 0;
+//     /* if(size > 100) size = 100;  */
+//     while(k < size)
+//     {
+//         int j;
+//         for(i = 0; i < d->depth + 3 ; i++) fprintf(self->dumper.out," ");
+//         for(j = 0; j < 16 && k < size; j++, k++)
+//         {
+//             fprintf(self->dumper.out,"%02x",buf[k]);
+//             if(k != size-1)
+//                 fprintf(self->dumper.out,", ");
+//         }
+//         fprintf(self->dumper.out,"\n");
+//     }
 
-    if(more)
-    {
-        for(i = 0; i < d->depth + 3 ; i++) fprintf(self->dumper.out," ");
-        fprintf(self->dumper.out,"... %lu more values\n", (unsigned long)more);
-    }
+//     if(more)
+//     {
+//         for(i = 0; i < d->depth + 3 ; i++) fprintf(self->dumper.out," ");
+//         fprintf(self->dumper.out,"... %lu more values\n", (unsigned long)more);
+//     }
 
-    for(i = 0; i < d->depth ; i++) fprintf(self->dumper.out," ");
-    fprintf(self->dumper.out,"} # %s %s \n",a->creator->op, a->name);
-    grib_context_free(d->context,buf);
-#endif
+//     for(i = 0; i < d->depth ; i++) fprintf(self->dumper.out," ");
+//     fprintf(self->dumper.out,"} # %s %s \n",a->creator->op, a->name);
+//     grib_context_free(d->context,buf);
 }
 
 static void dump_values(grib_dumper* d, grib_accessor* a)
@@ -551,7 +549,7 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
     if ((a->flags & GRIB_ACCESSOR_FLAG_DUMP) == 0)
         return;
 
-    grib_value_count(a, &count);
+    a->value_count(&count);
     size = count;
     if (size == 1) {
         dump_double(d, a, NULL);
@@ -564,7 +562,7 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
 
     if ((d->option_flags & GRIB_DUMP_FLAG_TYPE) != 0) {
         char type_name[32]     = "";
-        const long native_type = grib_accessor_get_native_type(a);
+        const long native_type = a->get_native_type();
         if (native_type == GRIB_TYPE_LONG)
             strcpy(type_name, "(int)");
         else if (native_type == GRIB_TYPE_DOUBLE)
@@ -598,7 +596,7 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
 
     fprintf(self->dumper.out, "\n");
 
-    err = grib_unpack_double(a, buf, &size);
+    err = a->unpack_double(buf, &size);
 
     if (err) {
         grib_context_free(d->context, buf);
@@ -613,7 +611,6 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
 
     k = 0;
     while (k < size) {
-#if 1
         int j;
         fprintf(self->dumper.out, "  ");
         for (j = 0; j < 5 && k < size; j++, k++) {
@@ -622,11 +619,6 @@ static void dump_values(grib_dumper* d, grib_accessor* a)
                 fprintf(self->dumper.out, ", ");
         }
         fprintf(self->dumper.out, "\n");
-#else
-
-        fprintf(self->dumper.out, "%d %g\n", k, buf[k]);
-
-#endif
     }
     if (more) {
         fprintf(self->dumper.out, "  ");
@@ -698,7 +690,7 @@ static void print_offset(FILE* out, grib_dumper* d, grib_accessor* a)
     grib_handle* h            = grib_handle_of_accessor(a);
 
     theBegin = a->offset - self->section_offset + 1;
-    theEnd = grib_get_next_position_offset(a) - self->section_offset;
+    theEnd = a->get_next_position_offset() - self->section_offset;
 
     if ((d->option_flags & GRIB_DUMP_FLAG_HEXADECIMAL) != 0 && a->length != 0) {
         if (theBegin == theEnd) {
